==> scorm_field-1.0.x-dev.tar.gz: scorm_field/README.md <==
# Scorm field

This module adds a scorm player field type that gives you the ability to add a scorm field to an entity. 

## Installation

Install the module like any other drupal module.

## Configration

Add a new field to your entity and choose "Scorm field". You will find it in the section "Reference fields".

### Decoupled mode

If you'd like to run the field in decoupled mode please visit to admin/config/system/scorm_field/settings

Please also create a view mode named "decoupled" for the entity to have attached the scorm field.

We recommend you install x_frame_options_configuration to allow your backend server to be accessed through an iframe on a different domain.


Endpoint to get a generated token.

Parameters: token (Token) (visit /admin/config/system/scorm_field/settings to generate token!)

Request: /api/scorm-field-scorm-get-access-token/{token}/{node_id}: GET

Response:

{
    "status": "success",
    "action": "token generated",
    "generated_token": "9503ce956440fb52",
    "iframe_source": "https://example.test/scorm-field-decoupled/1167/9503ce956440fb52/0"
}

Attention! Once the token has been used, it becomes invalid. So accessing the iframe source is only possible with a valid token. If you refresh the page, please trigger a new token for the iframe source.

Get Scorm Report:

Request: /api/scorm-field-scorm-report/{NID}: GET

Parameters: nid (int)
Filter by user simply attach ?user_uuid={UUID}

Response:

```

{
    "status": "success",
    "action": "scorm_report",
    "object": {
        "3": {
            "id": [
                {
                    "value": 3
                }
            ],
            "uuid": [
                {
                    "value": "9e3af963-2a54-4311-b363-40a309a8a6d6"
                }
            ],
            "uid": [
                {
                    "target_id": 3,
                    "target_type": "user",
                    "target_uuid": "44fc2be8-da2f-11e5-b5d2-0a1d41d68578",
                    "url": "/user/3/home"
                }
            ],
            "nid": [
                {
                    "target_id": 27,
                    "target_type": "node",
                    "target_uuid": "5519b5e5-3a49-4d99-9e49-ba3e77def843",
                    "url": "/node/27"
                }
            ],
            "created": [
                {
                    "value": "2024-06-17T12:06:38+00:00",
                    "format": "Y-m-d\\TH:i:sP"
                }
            ],
            "changed": [
                {
                    "value": "2024-06-17T12:06:38+00:00",
                    "format": "Y-m-d\\TH:i:sP"
                }
            ],
            "score_raw": [
                {
                    "value": 60
                }
            ],
            "score_max": [
                {
                    "value": 100
                }
            ],
            "score_min": [
                {
                    "value": 0
                }
            ],
            "status": [
                {
                    "value": "failed"
                }
            ],
            "ip": [
                {
                    "value": "xxx.xxx.xxx"
                }
            ],
            "session_uuid": []
        }
    }
}

```

Get Scorm Data:

Request: /api/scorm-data/{user_id}: GET

Parameters: user_id (string) UUID of the user
Filter by required nodes ?nids=[1,2,3,4]

Response:

```

{
    "status": "success",
    "action": "scorm_data",
    "data": {
        "3169": true,
        "3189": true
    }
}

```

==> scorm_field-2.0.x-dev.tar.gz: scorm_field/README.md <==
# Scorm field

This module adds a scorm player field type that gives you the ability to add a scorm field to an entity. 

## Installation

Install the module like any other drupal module.

## Configration

Add a new field to your entity and choose "Scorm field". You will find it in the section "Reference fields".

### Decoupled mode

If you'd like to run the field in decoupled mode please visit to admin/config/system/scorm_field/settings

Please also create a view mode named "decoupled" for the entity to have attached the scorm field.

We recommend you install x_frame_options_configuration to allow your backend server to be accessed through an iframe on a different domain.


Endpoint to get a generated token.

Parameters: token (Token) (visit /admin/config/system/scorm_field/settings to generate token!)

Request: /api/scorm-field-scorm-get-access-token/{token}/{node_id}/{user_id}: GET

Response Values:

status (bool) - Example: Success or failed
action (string)
generated_token (string) - Example: 45c2f174e7327608+
force_new_attempt (bool) - TRUE or FALSE
attempt_exists (bool) - TRUE of FALSE
attempt_uuid (string) - The uuid of the attempt.
iframe_source (string) - The url to the source on the server.
attempt_config (object) - Attempt config settings for the frontend.

Response:

```

{
    "status": "success",
    "action": "token generated",
    "generated_token": "45c2f174e7327608",
    "force_new_attempt": false,
    "attempt_exists": true,
    "attempt_uuid": "ecb3d909-0219-4c09-9d1e-fa2210a0e475",
    "iframe_source": "https://example.com/scorm-field-decoupled/59/45c2f174e7327608?uid=75a02cda-9413-4611-86b1-ccee37d2bd45&attempt_uuid=ecb3d909-0219-4c09-9d1e-fa2210a0e475",
    "attempt_config": {
        "question": "Es gibt bereits einen Versucht. Soll der Versuch fortgesetzt werden oder ein neuer Versuch gestartet werden?",
        "start_new_attempt_label": "Neuen Versuch starten",
        "proceed_attempt_label": "Versuch fortsetzen"
    }
}

```

Endpoint for creating attempts in decoupled mode:

Request: /api/scorm-field-scorm-create-attempt?_format=json

Request Body:

{
    "token": TOKEN_VALUE,
    "node_id": ###,
    "user_id": UUID_USER or 0

}


Response:

```

{
    "status": "success",
    "action": "token generated",
    "generated_token": "48051aa8d86ce4c6",
    "attempt_uuid": "9c6e899d-fa77-4252-801f-1d2fc86dc9ef",
    "iframe_source": "https://example.com/scorm-field-decoupled/59/48051aa8d86ce4c6?uid=75a02cda-9413-4611-86b1-ccee37d2bd45&attempt_uuid=9c6e899d-fa77-4252-801f-1d2fc86dc9ef"
}

```


Attention! Once the token has been used, it becomes invalid. So accessing the iframe source is only possible with a valid token. If you refresh the page, please trigger a new token for the iframe source.

Get Scorm Report:

Request: /api/scorm-field-scorm-report/{NID}: GET

Parameters: nid (int)
Filter by user simply attach ?user_uuid={UUID}

Response:

```

{
    "status": "success",
    "action": "scorm_report",
    "object": {
        "3": {
            "id": [
                {
                    "value": 3
                }
            ],
            "uuid": [
                {
                    "value": "9e3af963-2a54-4311-b363-40a309a8a6d6"
                }
            ],
            "uid": [
                {
                    "target_id": 3,
                    "target_type": "user",
                    "target_uuid": "44fc2be8-da2f-11e5-b5d2-0a1d41d68578",
                    "url": "/user/3/home"
                }
            ],
            "nid": [
                {
                    "target_id": 27,
                    "target_type": "node",
                    "target_uuid": "5519b5e5-3a49-4d99-9e49-ba3e77def843",
                    "url": "/node/27"
                }
            ],
            "created": [
                {
                    "value": "2024-06-17T12:06:38+00:00",
                    "format": "Y-m-d\\TH:i:sP"
                }
            ],
            "changed": [
                {
                    "value": "2024-06-17T12:06:38+00:00",
                    "format": "Y-m-d\\TH:i:sP"
                }
            ],
            "score_raw": [
                {
                    "value": 60
                }
            ],
            "score_max": [
                {
                    "value": 100
                }
            ],
            "score_min": [
                {
                    "value": 0
                }
            ],
            "status": [
                {
                    "value": "failed"
                }
            ],
            "ip": [
                {
                    "value": "xxx.xxx.xxx"
                }
            ],
            "session_uuid": []
        }
    }
}

```

Get Scorm Data:

Request: /api/scorm-data/{user_id}: GET

Parameters: user_id (string) UUID of the user
Filter by required nodes ?nids=[1,2,3,4]

Response:

```

{
    "status": "success",
    "action": "scorm_data",
    "data": {
        "3169": true,
        "3189": true
    }
}

```
